@@ -1,5 +1,4 @@
 """Module relatif aux structures de données."""
-from collections import deque
 import random
 from collections import deque
 from dataclasses import dataclass
@@ -8,6 +7,7 @@ from typing import Any, Deque, Dict, Iterator, List, Optional, Tuple, Union
 
 from pkg_resources import get_distribution
 
+
 class Pile:
     """Classe représentant une pile"""
 
@@ -71,7 +71,7 @@ class File:
 
     def enfiler(self, élément):
         """Ajoute l'élément à la queue la file."""
-        self._data.appendgauche(élément)
+        self._data.appendleft(élément)
 
     def défiler(self):
         """Retire l'élément à la tête de la file et le renvoie."""
@@ -117,6 +117,7 @@ class File:
 https://github.com/joowani/binarytree/commit/9ad3616ff61b1cc0c58e126ebe38841045787431
 """
 
+
 class BinaryTreeError(Exception):
     """Base (catch-all) binarytree exception."""
 
@@ -191,7 +192,7 @@ def _get_coords(
             edges.append((x // 2, y - 1, x, y))
         x += 1
         # check if level is full
-        if x == 2 ** y:
+        if x == 2**y:
             x = 0
             y += 1
     return nodes, edges
@@ -243,7 +244,7 @@ def generate_svg(valeurs: List[Union[float, int, None]]) -> str:
     def scalex(x: int, y: int) -> float:
         depth = y_max - y
         # offset
-        x = 2 ** (depth + 1) * x + 2 ** depth - 1
+        x = 2 ** (depth + 1) * x + 2**depth - 1
         return 1 + node_size + x_scale * x / 2
 
     def scaley(y: int) -> float:
@@ -280,7 +281,6 @@ from typing import Any, Dict, Iterator, List, Optional, Tuple, Union
 
 from pkg_resources import get_distribution
 
-
 gauche_FIELD = "gauche"
 droite_FIELD = "droite"
 VAL_FIELDS = ("val", "valeur", "étiquette")
@@ -433,13 +433,19 @@ class ArbreBinaire:
         """
         if attr == gauche_FIELD:
             if obj is not None and not isinstance(obj, ArbreBinaire):
-                raise ArbreBinaireTypeError("gauche child must be a ArbreBinaire instance")
+                raise ArbreBinaireTypeError(
+                    "gauche child must be a ArbreBinaire instance"
+                )
         elif attr == droite_FIELD:
             if obj is not None and not isinstance(obj, ArbreBinaire):
-                raise ArbreBinaireTypeError("droite child must be a ArbreBinaire instance")
+                raise ArbreBinaireTypeError(
+                    "droite child must be a ArbreBinaire instance"
+                )
         elif attr in VAL_FIELDS:
             if not isinstance(obj, (float, int, str)):
-                raise ArbreBinaireValeurError("node valeur must be a float or int or str")
+                raise ArbreBinaireValeurError(
+                    "node valeur must be a float or int or str"
+                )
             # On met à jour tous les attributs
             # TODO Est-ce une bonne idée? ou doit-on imposer une API plus stricte?
             for attr in VAL_FIELDS:
@@ -709,11 +715,15 @@ class ArbreBinaire:
         try:
             parent = self.__getitem__(parent_index)
         except ArbreBinaireNotFoundError:
-            raise ArbreBinaireNotFoundError("no node to delete at index {}".format(index))
+            raise ArbreBinaireNotFoundError(
+                "no node to delete at index {}".format(index)
+            )
 
         child_attr = gauche_FIELD if index % 2 == 1 else droite_FIELD
         if getattr(parent, child_attr) is None:
-            raise ArbreBinaireNotFoundError("no node to delete at index {}".format(index))
+            raise ArbreBinaireNotFoundError(
+                "no node to delete at index {}".format(index)
+            )
 
         setattr(parent, child_attr, None)
 
@@ -1766,7 +1776,9 @@ def _is_symmetric(root: Optional[ArbreBinaire]) -> bool:
     :rtype: bool
     """
 
-    def symmetric_helper(gauche: Optional[ArbreBinaire], droite: Optional[ArbreBinaire]) -> bool:
+    def symmetric_helper(
+        gauche: Optional[ArbreBinaire], droite: Optional[ArbreBinaire]
+    ) -> bool:
         if gauche is None and droite is None:
             return True
         if gauche is None or droite is None:
@@ -1829,7 +1841,7 @@ def _generate_random_leaf_count(height: int) -> int:
     :return: Random leaf count.
     :rtype: int
     """
-    max_leaf_count = 2 ** height
+    max_leaf_count = 2**height
     half_leaf_count = max_leaf_count // 2
 
     # A very naive way of mimicking normal distribution
@@ -1853,7 +1865,10 @@ def _generate_random_node_valeurs(height: int) -> List[int]:
 
 
 def _build_tree_string(
-    root: Optional[ArbreBinaire], curr_index: int, index: bool = False, delimiter: str = "-"
+    root: Optional[ArbreBinaire],
+    curr_index: int,
+    index: bool = False,
+    delimiter: str = "-",
 ) -> Tuple[List[str], int, int, int]:
     """Recursively walk down the binary tree and build a pretty-print string.
 
@@ -2009,7 +2024,7 @@ def _get_tree_properties(root: ArbreBinaire) -> ArbreBinaireProperties:
         size=size,
         is_max_heap=is_complete and is_descending,
         is_min_heap=is_complete and is_ascending,
-        is_perfect=leaf_count == 2 ** max_leaf_depth,
+        is_perfect=leaf_count == 2**max_leaf_depth,
         is_strict=is_strict,
         is_complete=is_complete,
         leaf_count=leaf_count,
@@ -2341,7 +2356,7 @@ def heap(
 
     if not is_perfect:
         # Randomly cut some of the leaf nodes away
-        random_cut = random.randint(2 ** height, len(valeurs))
+        random_cut = random.randint(2**height, len(valeurs))
         valeurs = valeurs[:random_cut]
 
     if is_max:
