@@ -17,7 +17,7 @@ def make_print_normal():
     return partial(PRINT_NORMAL)
 
 
-def rep2dot(racine, only_dirs=False, include_files_patterns=[]) -> str:
+def rep2dot(racine, include_files_patterns=["*"]) -> str:
     """Renvoie un fichier dot d'une structure d'une hiérarchie de répértoire"""
     # numérote les noeuds n0 n1...
     # en stockant le nom du noeud dans un
@@ -34,21 +34,18 @@ def rep2dot(racine, only_dirs=False, include_files_patterns=[]) -> str:
             posix = dir.as_posix()
             nodes[posix] = f"n{i}"
             dot += f'{nodes[posix]} [shape="folder", label="{dir.name}"];\n'
-            dot += f'{nodes[root]}-> {nodes[posix]};\n'
+            dot += f"{nodes[root]}-> {nodes[posix]};\n"
         # fichiers
-        if not only_dirs:
-            for file in files:
-                file = Path(f"{root}/{file}")
-                if sum([file.match(pattern) for pattern in include_files_patterns]) == 0:
-                    continue
-                i += 1
-                posix = file.as_posix()
-                nodes[posix] = f"n{i}"
-                dot += f'{nodes[posix]} [shape="note", label="{file.name}"];\n'
-                dot += f'{nodes[root]}-> {nodes[posix]};\n'
+        for file in files:
+            file = Path(f"{root}/{file}")
+            if sum([file.match(pattern) for pattern in include_files_patterns]) == 0:
+                continue
+            i += 1
+            posix = file.as_posix()
+            nodes[posix] = f"n{i}"
+            dot += f'{nodes[posix]} [shape="note", label="{file.name}"];\n'
+            dot += f"{nodes[root]}-> {nodes[posix]};\n"
 
     dot += "}"
-        
-    print(dot)
 
     return dot
