@@ -5,17 +5,8 @@ import math
 
 import pytest
 
-from lyceum.repr import (
-    ascii2bin,
-    bin2ascii,
-    bin2dec,
-    bin2float,
-    dec2bin,
-    dec2hex,
-    hex2dec,
-    hex2txt,
-    txt2hex,
-)
+from lyceum.repr import (ascii2bin, bin2ascii, bin2dec, bin2float, dec2bin,
+                         dec2hex, hex2dec, hex2txt, txt2hex)
 
 
 def test_bin():
